@@ -5,7 +5,10 @@ import ctypes as ct
 import numpy as np
 from aug_sfutils import sfdics, str_byt, sfread
 
-sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
+sfhlib = '/afs/ipp/aug/ads/lib64/@sys/libsfh8.so.20201118'
+if not os.path.isfile(sfhlib):
+    sfhlib = '/afs/ipp/aug/ads/lib64/amd64_sles11/libsfh8.so.20201118'
+
 libsfh = ct.cdll.LoadLibrary(sfhlib)
 
 logger = logging.getLogger('aug_sfutils.sfh')
@@ -109,7 +112,7 @@ class SFH:
 
         pss = str_byt.to_str(ps)
         pns = str_byt.to_str(pn)
-        if pss not in self.sfhead.parsets():
+        if pss not in self.sfhead.parsets:
             logger.debug('%s it not a parameter set', pss)
             return
 
