@@ -516,7 +516,7 @@ class SFREAD:
                     meta.dmin = data[0]
                     meta.dmax = data[1]
                     data = np.squeeze(data[2:]) # no array if n_items=1
-                dj0 = 8 * ( (bytlen + 7)//8 )
+                dj0 = str_byt.next8(bytlen)
                 j0 += dj0
             else: # faulty dfmt
                 break
