@@ -136,7 +136,7 @@ class WW:
             _format  = ct.byref(format)
             _indices = ct.byref(c_indices)
 
-            logger.debug(signame)
+#            logger.debug(signame)
             result = libddww.wwoinfo_(_error, self._diaref, name, _typ, \
                      _format, _ntval, _items, _indices, lname)
 
@@ -359,7 +359,7 @@ class WW:
             if getError(error):
                 raise Exception('ww.shotfile.SetAreabase: Error writing areabase %s' %areaname)
             else:
-                logger.info('Written Areabase %s, sizes %d %d %d', areaname, *sizes[:3])
+                logger.info('Written Areabase %s, sizes %d %d %d', areaname, *csizes[:3])
 
 
     def SetParameter(self, set_name, par_name, data):
@@ -469,14 +469,13 @@ def write_sf(nshot, data_d, sfhdir, diag, exp='AUGD'):
 
     otype = {}
     for obj, data in data_d.items():
-        logger.debug(obj)
         otype[obj] = ww._wwoinfo(obj)['otype']
         if otype[obj] == TimeBase:
             ww.SetObject(obj, data)
 
     for obj, data in data_d.items():
         if otype[obj] == AreaBase:
-            ww.SetObject(obj, data)
+            ww.SetObject(obj, data, tim_axis=0)
 
     for obj, data in data_d.items():
         if otype[obj] == ParamSet:
